import { ChatInputCommandInteraction, PermissionFlagsBits, SlashCommandBuilder } from "discord.js";
import { IsNull } from "typeorm";
import { Badword, database } from "../data";

const builder = new SlashCommandBuilder();
builder.setName("showblocklist");
builder.setDescription("Shows the blocklist of this server");
builder.setDMPermission(false);
builder.setDefaultMemberPermissions(PermissionFlagsBits.ManageChannels);

async function execute(interaction: ChatInputCommandInteraction): Promise<void> {
    if (!interaction.inGuild()) throw new Error("Command was executed outside guild context");
    
    const guildBadWords = await database.getRepository(Badword).find({
        select: {
            value: true
        },
        where: {
            guildID: interaction.guildId
        }
    });
    const globalBadWords = await database.getRepository(Badword).find({
        where: {
            guildID: IsNull()
        }
    });

    interaction.reply({
        content: `\`\`\`Global bad word list\`\`\`\n||${globalBadWords.map((word) => word.value).reduce((prev, next) => prev + ", " + next, "").slice(2)} ||\n\`\`\`Local server bad word list (${guildBadWords.length}/100)\`\`\`\n||${guildBadWords.map((word) => word.value).reduce((prev, next) => prev + ", " + next, "").slice(2)} ||`,
        ephemeral: true
    }).catch(() => {});
}

export {
    builder,
    execute
}